<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 01/09/2005 *
 * ===================                          Last change: 01/09/2005 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : beg.php                                          *
 * -------------------------------------------------------------------- *
 * Short description : Beg link for members                             *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Bettel-Link fuer Mitglieder                      *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2011 by Mailer Developer Team                   *
 * For more information visit: http://www.mxchange.org                  *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Load security stuff here
require('inc/libs/security_functions.php');

// Init start time
$GLOBALS['startTime'] = microtime(true);

// Set module
$GLOBALS['module'] = 'beg';
$GLOBALS['output_mode'] = -1;
$errorCode = null;

// Load the required file(s)
require('inc/config-global.php');

// Set content type
setContentType('text/html');

// Is the 'beg' extension active?
redirectOnUninstalledExtension('beg');

// Check for userid
if (isGetRequestParameterSet('userid')) {
	// Init variables
	$points = '0';

	// Don't pay is the default...
	$pay = false;

	// Validate if it is not a number
	if (isNicknameUsed(getRequestParameter('userid'))) {
		// Is the nickname extension there?
		if (isExtensionActive('nickname')) {
			// Maybe we have found a nickname?
			fetchUserData(getRequestParameter('userid'), 'nickname');
		} else {
			// Nickname entered but nickname is not active
			$errorCode = getCode('EXTENSION_PROBLEM');
		}
	} else {
		// Direct userid
		fetchUserData(getRequestParameter('userid'));
	}

	// Check if locked in so don't pay points
	$status = 'failed';

	// Check if account was found
	if ((isUserDataValid()) && (getUserData('status') == 'CONFIRMED')) {
		/*
		 * Multiply configured values with 100000 and divide with 100000 so we can also handle small values
		 * If we need more number behind the decimal dot then we just need to increase all these three
		 * numbers matching to the numbers behind the decimal dot. Simple! ;-)
		 */
		$points = mt_rand((getBegPoints() * 100000), (getBegPointsMax() * 100000)) / 100000;

		// Set nickname / userid for template
		$content['userid'] = getRequestParameter('userid');
		$content['clicks'] = (getUserData('beg_clicks') + 1);
		$content['banner'] = loadTemplate('beg_banner', true);
		$content['points'] = $points;
	} // END - if

	// User id valid and not webmaster's id?
	if ((isValidUserId(getUserData('userid'))) && (getBegUserid() != getUserData('userid'))) {
		// Update counter
		SQL_QUERY_ESC("UPDATE `{?_MYSQL_PREFIX?}_user_data` SET `beg_clicks`=`beg_clicks`+1 WHERE `userid`=%s LIMIT 1",
			array(getUserData('userid')), __FILE__, __LINE__);

		// Check for last entry for userid w/o IP number
		$result = SQL_QUERY_ESC("SELECT `id` FROM `{?_MYSQL_PREFIX?}_beg_ips` WHERE (`timeout` > (UNIX_TIMESTAMP() - {?beg_timeout?}) OR (`timeout` > (UNIX_TIMESTAMP() - {?beg_userid_timeout?}) AND `userid`=%s)) AND (`remote_ip`='%s' OR `sid`='%s') LIMIT 1",
			array(getUserData('userid'), detectRemoteAddr(), session_id()), __FILE__, __LINE__);

		// Entry not found, points set and not logged in?
		if (((SQL_HASZERONUMS($result)) || (isAdmin())) && ($points > 0) && (!isMember()) && (getBegPayMode() == 'NONE')) {
			// Admin is testing?
			if (!isAdmin()) {
				/*
				 * Remember remote address, userid and timestamp for next click
				 * but only when there is no admin begging.
				 * Admins shall be able to test it!
				 */
				SQL_QUERY_ESC("INSERT INTO `{?_MYSQL_PREFIX?}_beg_ips` (`userid`, `remote_ip`,`sid`, `timeout`) VALUES ('%s','%s','%s', UNIX_TIMESTAMP())",
					array(
						getUserData('userid'),
						detectRemoteAddr(),
						session_id()
					), __FILE__, __LINE__);

				// Was is successfull?
				$pay (!SQL_HASZEROAFFECTED());
			} else {
				// Is admin!
				$pay = true;
			}

			// Pay points?
			if ($pay === true) {
				// Add points to user or begging rallye account
				if (addPointsBeg(getUserData('userid'), $points)) {
					// Set 'done' message
					$content['message'] = loadTemplate('beg_done', true, $content);
				} else {
					// Error!
					$content['message'] = loadTemplate('beg_failed', true, $content);
				}
			} else {
				// Error!
				$content['message'] = loadTemplate('beg_failed', true, $content);
			}
		} elseif (isMember()) {
			// Logged in user found
			$content['message'] = loadTemplate('beg_login', true, $content);
		} elseif (getBegPayMode() != 'NONE') { // Other pay-mode active!
			// Load message template depending on pay-mode
			$content['message'] = loadTemplate('beg_pay_mode_'.strtolower(getBegPayMode()), true, $content);
			$pay = true;
		} else {
			// Clicked received while reload lock is active
			$content['message'] = loadTemplate('beg_failed', true, $content);
		}

		// Free memory
		SQL_FREERESULT($result);

		// Include header
		loadIncludeOnce('inc/header.php');

		// Load final template
		loadTemplate('beg_link', false, $content);

		// Tracker code enabled? (We don't track users here!
		if ((getBegPayMode() != 'NONE') && ($pay === true)) {
			// Prepare content for template
			// @TODO Opps, what is missing here???
			$content = array(
			);

			// Include config-depending template
			loadTemplate('beg_pay_code_'.strtolower(getBegPayMode()), false, $content);
		} elseif (($pay === false) && (!isset($content['message']))) {
			// Cannot pay! :-(
			$content['message'] = loadTemplate('beg_failed', true);
		}

		// Include footer
		loadIncludeOnce('inc/footer.php');
	} elseif ((getUserData('status') != 'CONFIRMED') && (getUserData('status') != 'failed')) {
		// Maybe locked/unconfirmed account?
		$errorCode = generateErrorCodeFromUserStatus();
	} elseif ((getUserData('userid') == '0') || (getUserData('status') == 'failed')) {
		// Inalid or locked account, so let's find out
		if (fetchUserData(getRequestParameter('userid'), 'nickname')) {
			// Locked account
			$errorCode = getCode('ACCOUNT_LOCKED');
		} else {
			// Invalid nickname! (404)
			$errorCode = getCode('USER_404');
		}
	} elseif (getUserData('userid') == getBegUserid()) {
		// Webmaster's id cannot beg for points!
		$errorCode = getCode('BEG_SAME_AS_OWN');
	}

	// Reload to index module if an error happens
	if (!empty($errorCode)) {
		redirectToUrl('modules.php?module=index&amp;code=' . $errorCode . '&amp;ext=beg');
	} // END - if
} else {
	// No userid entered
	redirectToUrl('modules.php?module=index');
}

// Really all done here... ;-)
shutdown();

// [EOF]
?>
