<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 07/24/2004 *
 * ===================                          Last change: 07/31/2004 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : what-holiday.php                                 *
 * -------------------------------------------------------------------- *
 * Short description : Holiday requests                                 *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Urlaubsschaltungen                               *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2011 by Mailer Developer Team                   *
 * For more information visit: http://www.mxchange.org                  *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	die();
} elseif (!isMember()) {
	redirectToIndexMemberOnlyModule();
}

// Add description as navigation point
addYouAreHereLink('member', __FILE__);

if ((!isExtensionActive('holiday')) && (!isAdmin())) {
	displayMessage(generateExtensionInactiveNotInstalledMessage('holiday'));
	return;
} // END - if

// Init content array
$content = array();

// Check for running mail orders in pool
$result1 = SQL_QUERY_ESC("SELECT
	`timestamp`
FROM
	`{?_MYSQL_PREFIX?}_pool`
WHERE
	`sender`=%s
ORDER BY
	`timestamp` DESC
LIMIT 1", array(getMemberId()), __FILE__, __LINE__);

// Check for sent mail orders in stats
$result2 = SQL_QUERY_ESC("SELECT
	`timestamp_ordered`
FROM
	`{?_MYSQL_PREFIX?}_user_stats`
WHERE
	`userid`=%s
ORDER BY
	`timestamp_ordered` DESC
LIMIT 1", array(getMemberId()), __FILE__, __LINE__);

if ((SQL_NUMROWS($result1) == 1) || (SQL_NUMROWS($result2) == 1)) {
	// Mail order found
	$content = merge_array($content, SQL_FETCHARRAY($result1));
	$content = merge_array($content, SQL_FETCHARRAY($result2));

	// Fix missing entries
	if (empty($content['timestamp'])) $content['timestamp'] = '0';
	if (empty($content['timestamp_ordered'])) $content['timestamp_ordered'] = '0';

	if ((($content['timestamp'] + getConfig('holiday_lock')) > time()) || (($content['timestamp_ordered'] + getConfig('holiday_lock')) > time())) {
		// Mail order is to close away!
		unsetPostRequestParameter('ok');
		unsetPostRequestParameter('stop');

		if (($content['timestamp'] + getConfig('holiday_lock')) > time()) {
			// Mail found in pool
			$stamp = $content['timestamp'];
		} else {
			// Mail found in stats
			$stamp = $content['timestamp_ordered'];
		}

		// Display message and exit here
		displayMessage(getMaskedMessage('MEMBER_HOLIDAY_ORDER', generateDateTime($stamp, 1)));
		return;
	}
} // END - if

// Free memory
SQL_FREERESULT($result1);
SQL_FREERESULT($result2);

if (isFormSent()) {
	// Check holiday request...
	$START = mktime(0, 0, 0, postRequestParameter('start_month'), postRequestParameter('start_day'), postRequestParameter('start_year'));
	$content['holiday_end']   = mktime(0, 0, 0, postRequestParameter('end_month')  , postRequestParameter('end_day')  , postRequestParameter('end_year')  );

	// Test both values
	$TEST = $content['holiday_end'] - $START;
	if (($TEST < 0) || ($TEST > (getOneDay() * getConfig('holiday_max'))) || ($START < time()) || ($content['holiday_end'] < time())) {
		// Time test failed
		unsetPostRequestParameter('ok');
	} else {
		// Everything went okay so let's store his request and send mails
		SQL_QUERY_ESC("INSERT INTO `{?_MYSQL_PREFIX?}_user_holidays` (`userid`, `holiday_start`, `holiday_end`, `comments`) VALUES ('%s','%s','%s','%s')",
			array(getMemberId(), $START, $content['holiday_end'], postRequestParameter('comments')), __FILE__, __LINE__);

		// Activate holiday system
		SQL_QUERY_ESC("UPDATE
	`{?_MYSQL_PREFIX?}_user_data`
SET
	`holiday_active`='N', `holiday_activated`=UNIX_TIMESTAMP()
WHERE
	`userid`=%s
LIMIT 1",
			array(getMemberId()), __FILE__, __LINE__);

		// Prepare constants
		$content['start_day']   = bigintval(postRequestParameter('start_day'));
		$content['start_month'] = $GLOBALS['month_descr'][postRequestParameter('start_month')];
		$content['start_year']  = bigintval(postRequestParameter('start_year'));
		$content['end_day']     = bigintval(postRequestParameter('end_day'));
		$content['end_month']   = $GLOBALS['month_descr'][postRequestParameter('end_month')];
		$content['end_year']    = bigintval(postRequestParameter('end_year'));
		$content['comments']    = postRequestParameter('comments');

		// Send mail to member
		$message = loadEmailTemplate('member_holiday_request', $content, getMemberId());
		sendEmail(getMemberId(), '{--MEMBER_HOLIDAY_SUBJECT--}', $message);

		// Send mail to all admins
		sendAdminNotification('{--ADMIN_HOLIDAY_SUBJECT--}', 'admin_holiday_request', $content, getMemberId());

		// Create task (we ignore the task id here)
		createNewTask('{--ADMIN_HOLIDAY_SUBJECT--}', $message, 'HOLIDAY_REQUEST', getMemberId());

		// Display message
		displayMessage('{--MEMBER_HOLIDAY_IS_ACTIVATED_NOW--}');
	}
} // END - if

// Holiday shall be ended now
if (isPostRequestParameterSet('stop')) {
	// Okay, end the holiday here...
	$result = SQL_QUERY_ESC("SELECT
	`holiday_active`, `holiday_activated`
FROM
	`{?_MYSQL_PREFIX?}_user_data`
WHERE
	`userid`=%s
LIMIT 1", array(getMemberId()), __FILE__, __LINE__);

	// Do we have an entry?
	if (SQL_NUMROWS($result) == 1) {
		// Merge arrays
		$content = merge_array($content, SQL_FETCHARRAY($result));

		if (($content['holiday_active'] == 'Y') && (($content['holiday_activated'] + getConfig('holiday_lock')) < time())) {
			// Load data
			$result2 = SQL_QUERY_ESC("SELECT
	`holiday_start`, `holiday_end`
FROM
	`{?_MYSQL_PREFIX?}_user_holidays`
WHERE
	`userid`=%s
LIMIT 1", array(getMemberId()), __FILE__, __LINE__);
			if (SQL_NUMROWS($result2) == 1) {
				// Data was found so merge it
				$content = merge_array($content, SQL_FETCHARRAY($result2));

				// Prepare it for the template
				$content['start'] = generateDateTime($content['holiday_start'], 3);
				$content['end']   = generateDateTime($content['holiday_end']  , 3);

				// Deactivate it now
				SQL_QUERY_ESC("UPDATE `{?_MYSQL_PREFIX?}_user_data`
SET
	`holiday_active`='N',
	`holiday_activated`=0
WHERE
	`userid`=%s
LIMIT 1",
					array(getMemberId()), __FILE__, __LINE__);

				// Remove entry
				SQL_QUERY_ESC("DELETE LOW_PRIORITY FROM
	`{?_MYSQL_PREFIX?}_user_holidays`
WHERE
	`userid`=%s
LIMIT 1",
					array(getMemberId()), __FILE__, __LINE__);

				// Send email to admin
				sendAdminNotification('{--ADMIN_HOLIDAY_DEAC_SUBJECT--}', 'admin_holiday_deactivated', $content, getMemberId());

				// Display message to user
				displayMessage('{--MEMBER_HOLIDAY_DEACTIVATED_NOW--}');
			} else {
				// Display message to user
				displayMessage('{--MEMBER_HOLIDAY_CANNOT_DEACTIVATE--}');
			}

			// Free result
			SQL_FREERESULT($result2);
		} elseif ($content['holiday_active'] == 'Y') {
			// To fast!
			displayMessage('{--MEMBER_HOLIDAY_LOCKED--}');
		}
	} else {
		// User not found
		displayMessage(getMaskedMessage('MEMBER_HOLIDAY_NOT_STOPPED_404', getMemberId()));
	}

	// Free result
	SQL_FREERESULT($result);
} // END - if

// If something is wrong or link in menu is just clicked display form
if ((!isFormSent()) && (!isPostRequestParameterSet('stop'))) {
	// Check if user is in holiday...
	$result = SQL_QUERY_ESC("SELECT
	`holiday_active`, `holiday_activated`
FROM
	`{?_MYSQL_PREFIX?}_user_data`
WHERE
	`userid`=%s
LIMIT 1", array(getMemberId()), __FILE__, __LINE__);
	$content = SQL_FETCHARRAY($result);
	SQL_FREERESULT($result);

	// Check for lock
	if (($content['holiday_activated'] + getConfig('holiday_lock')) < time()) {
		// User can deactivate his holiday request
		switch ($content['holiday_active']) {
			case 'Y': // Display deactivation form
				// Load starting and ending date
				$result = SQL_QUERY_ESC("SELECT
	`holiday_start`, `holiday_end`
FROM
	`{?_MYSQL_PREFIX?}_user_holidays`
WHERE
	`userid`=%s
LIMIT 1", array(getMemberId()), __FILE__, __LINE__);
				if (SQL_NUMROWS($result) == 1) {
					// Data was found so merge it
					$content = merge_array($content, SQL_FETCHARRAY($result));

					// Prepare it for the template
					$content['start'] = generateDateTime($content['holiday_start'] , 3);
					$content['end']   = generateDateTime($content['holiday_end']   , 3);
					$content['lock']  = generateDateTime($content['holiday_activated'], 1);

					// Load template
					loadTemplate('member_holiday_deactivate', false, $content);
				} else {
					// Free memory
					SQL_FREERESULT($result);

					// Remove entry and reload URL
					SQL_QUERY_ESC("UPDATE
	`{?_MYSQL_PREFIX?}_user_data`
SET
	`holiday_active`='N'
WHERE
	`userid`=%s
LIMIT 1",
						array(getMemberId()), __FILE__, __LINE__);
					redirectToUrl('modules.php?module=login&amp;what=holiday');
					return;
				}

				// Free result
				SQL_FREERESULT($result);
				break;

			case 'N': // Display activation form
				// Cache timestamps
				$startingStamp = time() + getOneDay();
				$endingStamp   = $startingStamp + (getOneDay() * getConfig('holiday_max'));

				// Starting day
				$content['start_day']   = addSelectionBox('day'  , getDay($startingStamp)  , 'start');
				$content['start_month'] = addSelectionBox('month', getMonth($startingStamp), 'start');
				$content['start_year']  = addSelectionBox('year' , getYear($startingStamp) , 'start');

				// Ending day
				$content['end_day']   = addSelectionBox('day'  , getDay($endingStamp)  , 'end');
				$content['end_month'] = addSelectionBox('month', getMonth($endingStamp), 'end');
				$content['end_year']  = addSelectionBox('year' , getYear($endingStamp) , 'end');

				// Output form
				loadTemplate('member_holiday_form', false, $content);
				break;
		} // END - switch
	} else {
		// To fast!
		displayMessage('{--MEMBER_HOLIDAY_LOCKED--}');
	}
} // END - if

// [EOF]
?>
